@@ -1,10 +1,12 @@
 mod builder;
+mod connector;
 mod interaction;
 
 pub use self::{builder::ClientBuilder, interaction::InteractionClient};
 
 #[allow(deprecated)]
 use crate::{
+    client::connector::Connector,
     error::{Error, ErrorType},
     request::{
         channel::{
@@ -106,16 +108,6 @@ use twilight_validate::{
     channel::ChannelValidationError, request::ValidationError, sticker::StickerValidationError,
 };
 
-#[cfg(feature = "hyper-rustls")]
-type HttpsConnector<T> = hyper_rustls::HttpsConnector<T>;
-#[cfg(all(feature = "hyper-tls", not(feature = "hyper-rustls")))]
-type HttpsConnector<T> = hyper_tls::HttpsConnector<T>;
-
-#[cfg(feature = "trust-dns")]
-type HttpConnector = hyper_trust_dns::TrustDnsHttpConnector;
-#[cfg(not(feature = "trust-dns"))]
-type HttpConnector = hyper::client::HttpConnector;
-
 /// Twilight's http client.
 ///
 /// Almost all of the client methods require authentication, and as such, the client must be
@@ -191,7 +183,7 @@ type HttpConnector = hyper::client::HttpConnector;
 pub struct Client {
     pub(crate) default_allowed_mentions: Option<AllowedMentions>,
     default_headers: Option<HeaderMap>,
-    http: HyperClient<HttpsConnector<HttpConnector>, Body>,
+    http: HyperClient<Connector>,
     proxy: Option<Box<str>>,
     ratelimiter: Option<Box<dyn Ratelimiter>>,
     timeout: Duration,
@@ -205,8 +197,7 @@ pub struct Client {
 }
 
 impl Client {
-    /// Create a new `hyper-rustls` or `hyper-tls` backed client with a token.
-    #[cfg_attr(docsrs, doc(cfg(any(feature = "hyper-rustls", feature = "hyper-tls"))))]
+    /// Create a new client with a token.
     pub fn new(token: String) -> Self {
         ClientBuilder::default().token(token).build()
     }
@@ -1640,10 +1631,28 @@ impl Client {
         UpdateTemplate::new(self, guild_id, template_code)
     }
 
-    /// Returns all active threads in the channel.
+    /// Returns all active threads in the guild.
     ///
     /// Includes public and private threads. Threads are ordered by their ID in
     /// descending order.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// # #[tokio::main] async fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// use twilight_http::Client;
+    /// use twilight_model::id::Id;
+    ///
+    /// let client = Client::new("my token".to_owned());
+    /// let guild_id = Id::new(234);
+    ///
+    /// let threads = client.active_threads(guild_id)
+    ///     .exec()
+    ///     .await?
+    ///     .model()
+    ///     .await?;
+    /// # Ok(()) }
+    /// ```
     pub const fn active_threads(&self, guild_id: Id<GuildMarker>) -> GetActiveThreads<'_> {
         GetActiveThreads::new(self, guild_id)
     }
