@@ -1,20 +1,24 @@
 use crate::{
     client::Client,
-    request::Request,
+    error::Error,
+    request::{Request, TryIntoRequest},
     response::{marker::ListBody, ResponseFuture},
     routing::Route,
 };
-use twilight_model::{application::command::Command, id::ApplicationId};
+use twilight_model::{
+    application::command::Command,
+    id::{marker::ApplicationMarker, Id},
+};
 
 /// Retrieve all global commands for an application.
 #[must_use = "requests must be configured and executed"]
 pub struct GetGlobalCommands<'a> {
-    application_id: ApplicationId,
+    application_id: Id<ApplicationMarker>,
     http: &'a Client,
 }
 
 impl<'a> GetGlobalCommands<'a> {
-    pub(crate) const fn new(http: &'a Client, application_id: ApplicationId) -> Self {
+    pub(crate) const fn new(http: &'a Client, application_id: Id<ApplicationMarker>) -> Self {
         Self {
             application_id,
             http,
@@ -25,10 +29,19 @@ impl<'a> GetGlobalCommands<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<Command>> {
-        let request = Request::from_route(&Route::GetGlobalCommands {
-            application_id: self.application_id.get(),
-        });
+        let http = self.http;
 
-        self.http.request(request)
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for GetGlobalCommands<'_> {
+    fn try_into_request(self) -> Result<Request, Error> {
+        Ok(Request::from_route(&Route::GetGlobalCommands {
+            application_id: self.application_id.get(),
+        }))
     }
 }
