@@ -4,8 +4,9 @@ use std::{
     fmt::{Display, Formatter, Result as FmtResult},
 };
 use twilight_model::{
-    channel::{permission_overwrite::PermissionOverwrite, ChannelType},
+    channel::ChannelType,
     guild::Permissions,
+    http::permission_overwrite::PermissionOverwrite,
     id::{
         marker::{ChannelMarker, RoleMarker},
         Id,
@@ -245,7 +246,7 @@ pub enum TextFieldsErrorType {
     /// The rate limit is invalid.
     RateLimitInvalid {
         /// The incorrect rate limit.
-        limit: u64,
+        limit: u16,
     },
     /// The topic is too long.
     TopicTooLong {
@@ -279,7 +280,7 @@ impl TextFieldsBuilder {
     /// This is used by [`rate_limit_per_user`].
     ///
     /// [`rate_limit_per_user`]: Self::rate_limit_per_user
-    pub const MAX_RATE_LIMIT: u64 = 21600;
+    pub const MAX_RATE_LIMIT: u16 = 21600;
 
     /// The maximum number of UTF-16 code points that can be in a channel topic.
     ///
@@ -348,7 +349,7 @@ impl TextFieldsBuilder {
     ///
     /// Returns a [`TextFieldsErrorType::RateLimitInvalid`] error type if the
     /// rate limit is invalid.
-    pub fn rate_limit_per_user(mut self, limit: u64) -> Result<Self, TextFieldsError> {
+    pub fn rate_limit_per_user(mut self, limit: u16) -> Result<Self, TextFieldsError> {
         if limit > Self::MAX_RATE_LIMIT {
             return Err(TextFieldsError {
                 kind: TextFieldsErrorType::RateLimitInvalid { limit },
@@ -501,7 +502,7 @@ impl VoiceFieldsBuilder {
     }
 
     /// Set the voice channel's bitrate.
-    pub const fn bitrate(mut self, bitrate: u64) -> Self {
+    pub const fn bitrate(mut self, bitrate: u32) -> Self {
         self.0.bitrate = Some(bitrate);
 
         self
@@ -515,7 +516,7 @@ impl VoiceFieldsBuilder {
     }
 
     /// Set the voice channel's user limit.
-    pub const fn user_limit(mut self, limit: u64) -> Self {
+    pub const fn user_limit(mut self, limit: u16) -> Self {
         self.0.user_limit = Some(limit);
 
         self
@@ -736,11 +737,9 @@ mod tests {
     use static_assertions::assert_impl_all;
     use std::fmt::Debug;
     use twilight_model::{
-        channel::{
-            permission_overwrite::{PermissionOverwrite, PermissionOverwriteType},
-            ChannelType,
-        },
+        channel::ChannelType,
         guild::Permissions,
+        http::permission_overwrite::{PermissionOverwrite, PermissionOverwriteType},
         id::Id,
     };
 
@@ -771,9 +770,10 @@ mod tests {
 
     fn overwrite() -> PermissionOverwrite {
         PermissionOverwrite {
-            allow: perms(),
-            deny: Permissions::empty(),
-            kind: PermissionOverwriteType::Role(Id::new(2)),
+            allow: Some(perms()),
+            deny: Some(Permissions::empty()),
+            id: Id::new(2),
+            kind: PermissionOverwriteType::Role,
         }
     }
 
@@ -836,9 +836,10 @@ mod tests {
                 kind: ChannelType::GuildVoice,
                 name: String::from("voicename"),
                 permission_overwrites: Some(vec![PermissionOverwrite {
-                    allow: perms(),
-                    deny: Permissions::empty(),
-                    kind: PermissionOverwriteType::Role(Id::new(2)),
+                    allow: Some(perms()),
+                    deny: Some(Permissions::empty()),
+                    id: Id::new(2),
+                    kind: PermissionOverwriteType::Role,
                 }]),
                 parent_id: None,
                 user_limit: Some(40),
@@ -874,9 +875,10 @@ mod tests {
                 name: String::from("textname"),
                 nsfw: Some(true),
                 permission_overwrites: Some(vec![PermissionOverwrite {
-                    allow: perms(),
-                    deny: Permissions::empty(),
-                    kind: PermissionOverwriteType::Role(Id::new(2)),
+                    allow: Some(perms()),
+                    deny: Some(Permissions::empty()),
+                    id: Id::new(2),
+                    kind: PermissionOverwriteType::Role
                 }]),
                 parent_id: None,
                 rate_limit_per_user: Some(4_000),
@@ -918,11 +920,14 @@ mod tests {
                     name: String::from("textname"),
                     nsfw: Some(true),
                     permission_overwrites: Some(vec![PermissionOverwrite {
-                        allow: Permissions::CONNECT
-                            | Permissions::SPEAK
-                            | Permissions::SEND_TTS_MESSAGES,
-                        deny: Permissions::empty(),
-                        kind: PermissionOverwriteType::Role(Id::new(2)),
+                        allow: Some(
+                            Permissions::CONNECT
+                                | Permissions::SPEAK
+                                | Permissions::SEND_TTS_MESSAGES
+                        ),
+                        deny: Some(Permissions::empty()),
+                        id: Id::new(2),
+                        kind: PermissionOverwriteType::Role,
                     }]),
                     parent_id: Some(Id::new(2)),
                     rate_limit_per_user: Some(4_000),
@@ -934,11 +939,14 @@ mod tests {
                     kind: ChannelType::GuildVoice,
                     name: String::from("voicename"),
                     permission_overwrites: Some(vec![PermissionOverwrite {
-                        allow: Permissions::CONNECT
-                            | Permissions::SPEAK
-                            | Permissions::SEND_TTS_MESSAGES,
-                        deny: Permissions::empty(),
-                        kind: PermissionOverwriteType::Role(Id::new(2)),
+                        allow: Some(
+                            Permissions::CONNECT
+                                | Permissions::SPEAK
+                                | Permissions::SEND_TTS_MESSAGES
+                        ),
+                        deny: Some(Permissions::empty()),
+                        id: Id::new(2),
+                        kind: PermissionOverwriteType::Role,
                     }]),
                     parent_id: Some(Id::new(2)),
                     user_limit: Some(40),
@@ -962,11 +970,14 @@ mod tests {
                     name: String::from("textname"),
                     nsfw: Some(true),
                     permission_overwrites: Some(vec![PermissionOverwrite {
-                        allow: Permissions::CONNECT
-                            | Permissions::SPEAK
-                            | Permissions::SEND_TTS_MESSAGES,
-                        deny: Permissions::empty(),
-                        kind: PermissionOverwriteType::Role(Id::new(2)),
+                        allow: Some(
+                            Permissions::CONNECT
+                                | Permissions::SPEAK
+                                | Permissions::SEND_TTS_MESSAGES
+                        ),
+                        deny: Some(Permissions::empty()),
+                        id: Id::new(2),
+                        kind: PermissionOverwriteType::Role,
                     }]),
                     parent_id: None,
                     rate_limit_per_user: Some(4_000),
@@ -978,11 +989,14 @@ mod tests {
                     kind: ChannelType::GuildVoice,
                     name: String::from("voicename"),
                     permission_overwrites: Some(vec![PermissionOverwrite {
-                        allow: Permissions::CONNECT
-                            | Permissions::SPEAK
-                            | Permissions::SEND_TTS_MESSAGES,
-                        deny: Permissions::empty(),
-                        kind: PermissionOverwriteType::Role(Id::new(2)),
+                        allow: Some(
+                            Permissions::CONNECT
+                                | Permissions::SPEAK
+                                | Permissions::SEND_TTS_MESSAGES
+                        ),
+                        deny: Some(Permissions::empty()),
+                        id: Id::new(2),
+                        kind: PermissionOverwriteType::Role,
                     }]),
                     parent_id: None,
                     user_limit: Some(40),
