@@ -1,68 +1,19 @@
 use crate::{
     client::Client,
-    request::{validate_inner, Request},
+    error::Error as HttpError,
+    request::{Request, TryIntoRequest},
     response::ResponseFuture,
     routing::Route,
 };
 use serde::Serialize;
-use std::{
-    error::Error,
-    fmt::{Display, Formatter, Result as FmtResult},
-};
 use twilight_model::{
     guild::PartialMember,
-    id::{GuildId, RoleId, UserId},
+    id::{
+        marker::{GuildMarker, RoleMarker, UserMarker},
+        Id,
+    },
 };
-
-/// Member cannot be added as configured.
-#[derive(Debug)]
-pub struct AddGuildMemberError {
-    kind: AddGuildMemberErrorType,
-}
-
-impl AddGuildMemberError {
-    /// Immutable reference to the type of error that occurred.
-    #[must_use = "retrieving the type has no effect if left unused"]
-    pub const fn kind(&self) -> &AddGuildMemberErrorType {
-        &self.kind
-    }
-
-    /// Consume the error, returning the source error if there is any.
-    #[allow(clippy::unused_self)]
-    #[must_use = "consuming the error and retrieving the source has no effect if left unused"]
-    pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>> {
-        None
-    }
-
-    /// Consume the error, returning the owned error type and the source error.
-    #[must_use = "consuming the error into its parts has no effect if left unused"]
-    pub fn into_parts(
-        self,
-    ) -> (
-        AddGuildMemberErrorType,
-        Option<Box<dyn Error + Send + Sync>>,
-    ) {
-        (self.kind, None)
-    }
-}
-
-impl Display for AddGuildMemberError {
-    fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
-        match &self.kind {
-            AddGuildMemberErrorType::NicknameInvalid => f.write_str("nickname length is invalid"),
-        }
-    }
-}
-
-impl Error for AddGuildMemberError {}
-
-#[derive(Debug)]
-#[non_exhaustive]
-pub enum AddGuildMemberErrorType {
-    /// Nickname is either empty or the length is more than 32 UTF-16
-    /// characters.
-    NicknameInvalid,
-}
+use twilight_validate::request::{nickname as validate_nickname, ValidationError};
 
 #[derive(Serialize)]
 struct AddGuildMemberFields<'a> {
@@ -74,28 +25,28 @@ struct AddGuildMemberFields<'a> {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub nick: Option<&'a str>,
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub roles: Option<&'a [RoleId]>,
+    pub roles: Option<&'a [Id<RoleMarker>]>,
 }
 
 #[must_use = "requests must be configured and executed"]
 pub struct AddGuildMember<'a> {
     fields: AddGuildMemberFields<'a>,
-    guild_id: GuildId,
+    guild_id: Id<GuildMarker>,
     http: &'a Client,
-    user_id: UserId,
+    user_id: Id<UserMarker>,
 }
 
 /// Add a user to a guild.
 ///
 /// An access token for the user with `guilds.join` scope is required. All other
-/// fields are optional. Refer to [the discord docs] for more information.
+/// fields are optional. See [Discord Docs/Add Guild Member].
 ///
-/// [the discord docs]: https://discord.com/developers/docs/resources/guild#add-guild-member
+/// [Discord Docs/Add Guild Member]: https://discord.com/developers/docs/resources/guild#add-guild-member
 impl<'a> AddGuildMember<'a> {
     pub(crate) const fn new(
         http: &'a Client,
-        guild_id: GuildId,
-        user_id: UserId,
+        guild_id: Id<GuildMarker>,
+        user_id: Id<UserMarker>,
         access_token: &'a str,
     ) -> Self {
         Self {
@@ -134,14 +85,12 @@ impl<'a> AddGuildMember<'a> {
     ///
     /// # Errors
     ///
-    /// Returns an [`AddGuildMemberErrorType::NicknameInvalid`] error type if
-    /// the nickname is too short or too long.
-    pub fn nick(mut self, nick: &'a str) -> Result<Self, AddGuildMemberError> {
-        if !validate_inner::nickname(&nick) {
-            return Err(AddGuildMemberError {
-                kind: AddGuildMemberErrorType::NicknameInvalid,
-            });
-        }
+    /// Returns an error of type [`Nickname`] if the nickname length is too
+    /// short or too long.
+    ///
+    /// [`Nickname`]: twilight_validate::request::ValidationErrorType::Nickname
+    pub fn nick(mut self, nick: &'a str) -> Result<Self, ValidationError> {
+        validate_nickname(nick)?;
 
         self.fields.nick.replace(nick);
 
@@ -149,7 +98,7 @@ impl<'a> AddGuildMember<'a> {
     }
 
     /// List of roles to assign the new member.
-    pub const fn roles(mut self, roles: &'a [RoleId]) -> Self {
+    pub const fn roles(mut self, roles: &'a [Id<RoleMarker>]) -> Self {
         self.fields.roles = Some(roles);
 
         self
@@ -159,16 +108,24 @@ impl<'a> AddGuildMember<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<PartialMember> {
+        let http = self.http;
+
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for AddGuildMember<'_> {
+    fn try_into_request(self) -> Result<Request, HttpError> {
         let mut request = Request::builder(&Route::AddGuildMember {
             guild_id: self.guild_id.get(),
             user_id: self.user_id.get(),
         });
 
-        request = match request.json(&self.fields) {
-            Ok(request) => request,
-            Err(source) => return ResponseFuture::error(source),
-        };
+        request = request.json(&self.fields)?;
 
-        self.http.request(request.build())
+        Ok(request.build())
     }
 }
