@@ -1,7 +1,16 @@
-use crate::{client::Client, request::Request, response::ResponseFuture, routing::Route};
+use crate::{
+    client::Client,
+    error::Error,
+    request::{Request, TryIntoRequest},
+    response::ResponseFuture,
+    routing::Route,
+};
 use twilight_model::{
-    channel::message::sticker::{Sticker, StickerId},
-    id::GuildId,
+    channel::message::sticker::Sticker,
+    id::{
+        marker::{GuildMarker, StickerMarker},
+        Id,
+    },
 };
 
 /// Returns a guild sticker by the guild's ID and the sticker's ID.
@@ -10,17 +19,14 @@ use twilight_model::{
 ///
 /// ```no_run
 /// use twilight_http::Client;
-/// use twilight_model::{
-///     channel::message::sticker::StickerId,
-///     id::GuildId,
-/// };
+/// use twilight_model::id::Id;
 ///
 /// # #[tokio::main]
 /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 /// let client = Client::new("my token".to_owned());
 ///
-/// let guild_id = GuildId::new(1).expect("non zero");
-/// let sticker_id = StickerId::new(2).expect("non zero");
+/// let guild_id = Id::new(1);
+/// let sticker_id = Id::new(2);
 /// let sticker = client
 ///     .guild_sticker(guild_id, sticker_id)
 ///     .exec()
@@ -32,13 +38,17 @@ use twilight_model::{
 /// # Ok(()) }
 /// ```
 pub struct GetGuildSticker<'a> {
-    guild_id: GuildId,
+    guild_id: Id<GuildMarker>,
     http: &'a Client,
-    sticker_id: StickerId,
+    sticker_id: Id<StickerMarker>,
 }
 
 impl<'a> GetGuildSticker<'a> {
-    pub(crate) const fn new(http: &'a Client, guild_id: GuildId, sticker_id: StickerId) -> Self {
+    pub(crate) const fn new(
+        http: &'a Client,
+        guild_id: Id<GuildMarker>,
+        sticker_id: Id<StickerMarker>,
+    ) -> Self {
         Self {
             guild_id,
             http,
@@ -50,11 +60,20 @@ impl<'a> GetGuildSticker<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Sticker> {
-        let request = Request::from_route(&Route::GetGuildSticker {
-            guild_id: self.guild_id.get(),
-            sticker_id: self.sticker_id.get(),
-        });
+        let http = self.http;
 
-        self.http.request(request)
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for GetGuildSticker<'_> {
+    fn try_into_request(self) -> Result<Request, Error> {
+        Ok(Request::from_route(&Route::GetGuildSticker {
+            guild_id: self.guild_id.get(),
+            sticker_id: self.sticker_id.get(),
+        }))
     }
 }
